==> fle-cli-1.1.6.tgz: package/lib/create.js <==
const fs = require('fs');
const path = require('path');
const inquirer = require('inquirer');
const chalk = require('chalk');
const utils = require('./utils');

module.exports = function (args) {
  inquirer.prompt([
    // {
    //   type: 'input',
    //   name: 'name',
    //   message: 'Project name',
    //   default: args[1]
    // },
    {
      type: 'list',
      name: 'type',
      message: 'Project type',
      choices: ['lib', 'react', 'vue', 'app'],
      default: 'lib'
    },
    {
      type: 'confirm',
      name: 'extract',
      message: 'Extract CSS in library ?',
      default: false,
      when (answers) {
        return answers.type === 'lib'
      }
    },
    {
      type: 'confirm',
      name: 'px2rem',
      message: 'Transform px to rem ?',
      default: false
    },
    {
      type: 'list',
      name: 'install',
      message: 'Install modules',
      choices: ['yarn', 'npm', 'ignore'],
      default: 'yarn'
    }
  ]).then(answers => {
    const originPath = path.join(__dirname, '../boilerplate', answers.type);
    const targetPath = path.join(process.cwd(), args[1]);

    fs.mkdirSync(targetPath);

    let tplPkg = require(path.join(originPath, 'package.json'));
    tplPkg.name = answers.name;
    if (answers.type === 'lib') {
      tplPkg['fle-settings'].extract = answers.extract;
    }
    tplPkg['fle-settings'].px2rem = answers.px2rem;
    tplPkg.author = utils.getGitUser();

    fs.writeFileSync(path.join(targetPath, 'package.json'), JSON.stringify(tplPkg, null, 2), { encoding: 'utf8' });

    utils.copy(originPath, targetPath);

    console.log('');

    // install modules
    if (answers.install === 'yarn') {
      utils.exec(`cd ${args[1]} && yarn`);
    } else if (answers.install === 'npm') {
      utils.exec(`cd ${args[1]} && npm install`);
    }

    if (answers.install !== 'ignore') {
      console.log(chalk.green('Install successfully!'));
      console.log('');
    }

    console.log('To start project you can:');
    console.log('');
    console.log(chalk.cyan(`  $ cd ${args[1]}`));
    if (answers.install === 'ignore') {
      console.log(chalk.cyan('  $ npm install'));
    }
    console.log(chalk.cyan('  $ fle dev'));
    console.log('');
  });
}

==> fle-cli-2.0.0.tgz: package/lib/create.js <==
const fs = require('fs');
const path = require('path');
const inquirer = require('inquirer');
const chalk = require('chalk');
const utils = require('./utils');

module.exports = function (args) {
  inquirer.prompt([
    // {
    //   type: 'input',
    //   name: 'name',
    //   message: 'Project name',
    //   default: args[1]
    // },
    {
      type: 'list',
      name: 'type',
      message: 'Project type',
      choices: ['lib', 'react', 'vue', 'app'],
      default: 'lib'
    },
    {
      type: 'confirm',
      name: 'extract',
      message: 'Extract CSS from library ?',
      default: false,
      when (answers) {
        return answers.type === 'lib'
      }
    },
    {
      type: 'confirm',
      name: 'rem',
      message: 'Use rem layout for mobile ?',
      default: false,
      when (answers) {
        return answers.type !== 'lib'
      }
    },
    {
      type: 'list',
      name: 'install',
      message: 'Install modules',
      choices: ['yarn', 'npm', 'ignore'],
      default: 'yarn'
    }
  ]).then(answers => {
    const originPath = path.join(__dirname, '../boilerplate', answers.type);
    const targetPath = path.join(process.cwd(), args[1]);

    fs.mkdirSync(targetPath);

    let tplPkg = require(path.join(originPath, 'package.json'));
    let tplFle = require(path.join(originPath, 'fle.json'));

    tplPkg.name = answers.name;
    tplPkg.author = utils.getGitUser();

    if (typeof answers.extract !== 'undefined') {
      tplFle.extract = answers.extract;
    }

    if (typeof answers.rem !== 'undefined') {
      tplFle.px2rem = answers.rem;
    }

    fs.writeFileSync(path.join(targetPath, 'package.json'), JSON.stringify(tplPkg, null, 2), { encoding: 'utf8' });
    fs.writeFileSync(path.join(targetPath, 'fle.json'), JSON.stringify(tplFle, null, 2), { encoding: 'utf8' });

    utils.copy(originPath, targetPath);

    console.log('');

    // install modules
    if (answers.install === 'yarn') {
      utils.exec(`cd ${args[1]} && yarn`);
    } else if (answers.install === 'npm') {
      utils.exec(`cd ${args[1]} && npm install`);
    }

    if (answers.install !== 'ignore') {
      console.log(chalk.green('Install successfully!'));
      console.log('');
    }

    console.log('To start project you can:');
    console.log('');
    console.log(chalk.cyan(`  $ cd ${args[1]}`));
    if (answers.install === 'ignore') {
      console.log(chalk.cyan('  $ npm install'));
    }
    console.log(chalk.cyan('  $ fle dev'));
    console.log('');
  });
}
